pub enum Error {
AtomIdx {
provided: u16,
bond_idx: usize,
atom: u8,
max: usize,
},
BondMult {
provided: u16,
bond_idx: usize,
},
AtomicNum {
provided: u8,
atom_idx: usize,
},
ParallelBonds {
bond1: usize,
bond2: usize,
},
}Expand description
A pre-condition violation that may cause undefined behavior when generating coordinates.
These pre-conditions correspond to those documented in gen_coords_unchecked.
Variants
AtomIdx
An atom index in a bond exceeded the maximum possible value
Fields
BondMult
One of the bond multiplicities was not ∈ {1,2,3}
Fields
AtomicNum
One of the atoms contained an atomic number for an atom that doesn’t exist
Fields
ParallelBonds
The provided bonds contained a parallel bond